@@ -6,4 +6,4 @@ from .POLQA.POLQA import cal_polqa
 from .SDR.SDR import cal_sdr
 from .STI.cal_sti import cal_sti
 from .STOI.STOI import *
-from resample.resampler import resample
\ No newline at end of file
+from .resample.resampler import resample
\ No newline at end of file
